sccoda package
==============

Subpackages
-----------

.. toctree::

   sccoda.model
   sccoda.util

Module contents
---------------

.. automodule:: sccoda
   :members:
   :undoc-members:
   :show-inheritance:
